@@ -78,8 +78,6 @@ static const xmlChar *model_xml_template =
 "        <Option Id=\"NonCollatedCopiesHW\" Type=\"String\" Default=\"true\"/>"
 "        <Option Id=\"CollatedCopiesHW\" Type=\"String\" Default=\"false\"/>"
 "        <Option Id=\"Collate\" Type=\"String\" Default=\"false\"/>"
-"        <Option Id=\"Duplex\" Type=\"String\" Default=\"true\"/>"
-"        <Option Id=\"Tumble\" Type=\"String\" Default=\"false\"/>"
 "        <Option Id=\"PrintToFile\" Type=\"String\" Default=\"false\" Locked=\"true\"/>"
 "        <Option Id=\"FileName\" Type=\"String\" Default=\"output.ps\"/>"
 "      </Option>"
@@ -128,8 +126,6 @@ static const xmlChar *model_unknown_xml_template =
 "        <Option Id=\"NonCollatedCopiesHW\" Type=\"String\" Default=\"true\"/>"
 "        <Option Id=\"CollatedCopiesHW\" Type=\"String\" Default=\"false\"/>"
 "        <Option Id=\"Collate\" Type=\"String\" Default=\"false\"/>"
-"        <Option Id=\"Duplex\" Type=\"String\" Default=\"true\"/>"
-"        <Option Id=\"Tumble\" Type=\"String\" Default=\"false\"/>"
 "        <Option Id=\"PrintToFile\" Type=\"String\" Default=\"false\" Locked=\"true\"/>"
 "        <Option Id=\"FileName\" Type=\"String\" Default=\"output.ps\"/>"
 "      </Option>"
@@ -483,7 +479,6 @@ gnome_print_cups_adjust_settings (GPANode	   *settings,
 				  GnomeCupsPrinter *printer)
 {
 	/* default to single sided */
-	gboolean duplex = FALSE, bind_short_edge = FALSE;
 	char *val;
 
 	val = gnome_cups_printer_get_option_value (printer, "PageSize");
@@ -502,6 +497,9 @@ gnome_print_cups_adjust_settings (GPANode	   *settings,
 	if (NULL == val)
 		val = gnome_cups_printer_get_option_value (printer, "KD03Duplex");	/* Kodak */
 	if (NULL != val) {
+		GPANode *job = gpa_node_lookup (settings, "Output.Job");
+		gboolean duplex = FALSE, bind_short_edge = FALSE;
+
 		/* we do not really need to ignore case, but it does not hurt */
 		if (g_ascii_strcasecmp (val, "None") == 0) {
 			/* this is the default */
@@ -515,11 +513,11 @@ gnome_print_cups_adjust_settings (GPANode	   *settings,
 			g_warning ("Unknown Duplex setting == '%s'", val);
 		}
 		g_free (val);
+		gpa_option_string_new (job, "Duplex",
+			duplex ? "true" : "false");
+		gpa_option_string_new (job, "Tumble",
+			(duplex && bind_short_edge) ? "true" : "false"); /* be anal */
 	}
-	gpa_node_set_path_value (settings, "Output.Job.Duplex",
-		duplex ? "true" : "false");
-	gpa_node_set_path_value (settings, "Output.Job.Tumble",
-		(duplex && bind_short_edge) ? "true" : "false"); /* be anal */
 }
 
 static void
@@ -712,7 +710,6 @@ stop_polling (GPAPrinter *printer)
 	g_object_unref (G_OBJECT (cupsprinter));
 }
 
-void gpa_module_polling (GPAPrinter *printer, gboolean polling);
 G_MODULE_EXPORT void gpa_module_polling (GPAPrinter *printer,
 					 gboolean polling)
 {
