@@ -34,6 +34,20 @@
 #include <libgnomeprint/gnome-print.h>
 #include "gp-transport-custom.h"
 
+#if !defined(HAVE_POPEN)
+#ifdef G_OS_WIN32
+#include <stdio.h>
+#define popen(f,m) _popen(f,m)
+#endif
+#endif
+
+#if !defined(HAVE_PCLOSE)
+#ifdef G_OS_WIN32
+#include <stdio.h>
+#define pclose(f) _pclose(f)
+#endif
+#endif
+
 static void gp_transport_custom_class_init (GPTransportCustomClass *klass);
 static void gp_transport_custom_init (GPTransportCustom *tcustom);
 
@@ -146,7 +160,13 @@ gp_transport_custom_open (GnomePrintTransport *transport)
 		command = g_strdup ("lpr");
 	}
 
-	tcustom->pipe = popen (command, "wb");
+	tcustom->pipe = popen (command,
+#ifdef G_OS_WIN32
+			       "wb"
+#else
+			       "w"
+#endif
+			       );
 
 	if (tcustom->pipe == NULL) {
 		g_warning ("Opening '%s' for output failed", command);
